#include <gnome.h>


void
on_exit_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_about_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_light_check1_toggled                (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_reset1_clicked                      (GtkButton       *button,
                                        gpointer         user_data);

void
on_light_check2_toggled                (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_reset2_clicked                      (GtkButton       *button,
                                        gpointer         user_data);

void
on_light_check3_toggled                (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_reset3_clicked                      (GtkButton       *button,
                                        gpointer         user_data);

void
on_reset4_clicked                      (GtkButton       *button,
                                        gpointer         user_data);

void
on_about_ok_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_gl_area_button_press_event          (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_gl_area_button_release_event        (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_gl_area_motion_notify_event         (GtkWidget       *widget,
                                        GdkEventMotion  *event,
                                        gpointer         user_data);
